==> deepin-calculator_5.7.12.orig.tar.gz: deepin-calculator-5.7.12/translations/deepin-calculator_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>運算式錯誤</translation>
    </message>
</context>
<context>
    <name>IconButton</name>
    <message>
        <source>Clear all memory</source>
        <translation>清除所有記憶體</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>清除歷史記錄</translation>
    </message>
</context>
<context>
    <name>InputEdit</name>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>全選</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>復原</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>重做</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>剪下</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>貼上</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Calculator</source>
        <translation>計算器</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>標準</translation>
    </message>
    <message>
        <source>Scientific</source>
        <translation>科學</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <source>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</source>
        <translation>計算器是一款簡單易用的桌面計算器，支持標準型、科學型、程式設計師型模式。</translation>
    </message>
    <message>
        <source>Programmer</source>
        <translation>程式設計師</translation>
    </message>
</context>
<context>
    <name>MemoryButton</name>
    <message>
        <source>Clear memory item</source>
        <translation>清除記憶體項</translation>
    </message>
    <message>
        <source>Clear all memory</source>
        <translation>清除所有記憶體</translation>
    </message>
    <message>
        <source>Memory recall</source>
        <translation>記憶體重新呼叫</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>添加到記憶體項</translation>
    </message>
    <message>
        <source>Memory add</source>
        <translation>記憶體增加</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>從記憶體項中減掉</translation>
    </message>
    <message>
        <source>Memory subtract</source>
        <translation>記憶體減少</translation>
    </message>
    <message>
        <source>Memory store</source>
        <translation>記憶體儲存</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>記憶體</translation>
    </message>
</context>
<context>
    <name>MemoryItemWidget</name>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Clear memory item</source>
        <translation>清除記憶體項</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>添加到記憶體項</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>從記憶體項中減掉</translation>
    </message>
</context>
<context>
    <name>MemoryWidget</name>
    <message>
        <source>Nothing saved in memory</source>
        <translation>記憶體中沒有資料</translation>
    </message>
</context>
<context>
    <name>ProExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>運算式錯誤</translation>
    </message>
</context>
<context>
    <name>ProListView</name>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
</context>
<context>
    <name>ProgramModule</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>算數移位</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>邏輯移位</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>循環移位</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>帶進位循環移位</translation>
    </message>
</context>
<context>
    <name>ProgrammerItemWidget</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>算數移位</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>邏輯移位</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>循環移位</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>帶進位循環移位</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Calculator</source>
        <translation>計算器</translation>
    </message>
</context>
<context>
    <name>SciExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>運算式錯誤</translation>
    </message>
</context>
<context>
    <name>SciHistoryWidget</name>
    <message>
        <source>History</source>
        <translation>歷史記錄</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>記憶體</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression error</source>
        <translation>運算式錯誤</translation>
    </message>
</context>
<context>
    <name>SimpleListModel</name>
    <message>
        <source>No history</source>
        <translation>無歷史記錄</translation>
    </message>
</context>
<context>
    <name>SimpleListView</name>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
</context>
</TS>

==> deepin-calculator_6.5.4.orig.tar.gz: deepin-calculator-6.5.4/translations/deepin-calculator_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>運算式錯誤</translation>
    </message>
</context>
<context>
    <name>IconButton</name>
    <message>
        <source>Clear all memory</source>
        <translation>清除所有記憶體</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>清除歷史記錄</translation>
    </message>
</context>
<context>
    <name>InputEdit</name>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>全選</translation>
    </message>
    <message>
        <source>Use thousands separator</source>
        <translation>切換為千分位</translation>
    </message>
    <message>
        <source>Use ten-thousands separator</source>
        <translation>切換為萬分位</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>復原</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>重做</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>剪下</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>貼上</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Calculator</source>
        <translation>計算器</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>標準</translation>
    </message>
    <message>
        <source>Scientific</source>
        <translation>科學</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>模式</translation>
    </message>
    <message>
        <source>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</source>
        <translation>計算器是一款簡單易用的桌面計算器，支持標準型、科學型、程式設計師型模式。</translation>
    </message>
    <message>
        <source>Programmer</source>
        <translation>程式設計師</translation>
    </message>
</context>
<context>
    <name>MemoryButton</name>
    <message>
        <source>Clear memory item</source>
        <translation>清除記憶體項</translation>
    </message>
    <message>
        <source>Clear all memory</source>
        <translation>清除所有記憶體</translation>
    </message>
    <message>
        <source>Memory recall</source>
        <translation>記憶體重新呼叫</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>添加到記憶體項</translation>
    </message>
    <message>
        <source>Memory add</source>
        <translation>記憶體增加</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>從記憶體項中減掉</translation>
    </message>
    <message>
        <source>Memory subtract</source>
        <translation>記憶體減少</translation>
    </message>
    <message>
        <source>Memory store</source>
        <translation>記憶體儲存</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>記憶體</translation>
    </message>
</context>
<context>
    <name>MemoryItemWidget</name>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Clear memory item</source>
        <translation>清除記憶體項</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>添加到記憶體項</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>從記憶體項中減掉</translation>
    </message>
</context>
<context>
    <name>MemoryWidget</name>
    <message>
        <source>Nothing saved in memory</source>
        <translation>記憶體中沒有資料</translation>
    </message>
</context>
<context>
    <name>ProExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>運算式錯誤</translation>
    </message>
</context>
<context>
    <name>ProListView</name>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
</context>
<context>
    <name>ProgramModule</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>算數移位</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>邏輯移位</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>循環移位</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>帶進位循環移位</translation>
    </message>
</context>
<context>
    <name>ProgrammerItemWidget</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>算數移位</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>邏輯移位</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>循環移位</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>帶進位循環移位</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Calculator</source>
        <translation>計算器</translation>
    </message>
</context>
<context>
    <name>SciExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>運算式錯誤</translation>
    </message>
</context>
<context>
    <name>SciHistoryWidget</name>
    <message>
        <source>History</source>
        <translation>歷史記錄</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>記憶體</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression error</source>
        <translation>運算式錯誤</translation>
    </message>
</context>
<context>
    <name>SimpleListModel</name>
    <message>
        <source>No history</source>
        <translation>無歷史記錄</translation>
    </message>
</context>
<context>
    <name>SimpleListView</name>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
</context>
</TS>
